@@ -123,14 +123,16 @@ class Aggregator(object):
         """Return a list of unique activities. Can't use set() b/c activities
         are dicts and therefore unhashable.
         """
-        unique = []
-        for a in activities:
-            # score/flags shouldn't affect activity of comparison
-            a['score'] = 0
-            a['flags'] = 0
-            if a in unique: continue
-            unique.append(a)
-        return unique
+        ignore_keys = ('score', 'flags', '_id')
+        unique_orig, unique_norm  = [], []
+        for orig in activities:
+            norm = orig.copy()
+            for k in ignore_keys:
+                if k in norm: del norm[k]
+            if norm in unique_norm: continue
+            unique_norm.append(norm)
+            unique_orig.append(orig)
+        return unique_orig
 
     def classify_activities(self, activities):
         """Return a list of activities with classfication flags added."""
